# -*- coding:utf-8 -*-
"""
Created on the 05/01/18
@author: Nicolas Thiebaut
@email: nkthiebaut@gmail.com
"""
import os

MODELS_DIR = os.path.join(os.path.dirname(os.path.dirname(os.path.realpath(__file__))), 'models')
